from __future__ import print_function

__author__ = 'Artur Barseghyan <artur.barseghyan@gmail.com>'
__copyright__ = 'Copyright (c) 2015 Artur Barseghyan'
__license__ = 'GPL 2.0/LGPL 2.1'

import unittest

from nonefield.tests.test_nonefield import *

if __name__ == '__main__':
    unittest.main()



__title__ = 'nonefield.tests.constants'
__author__ = 'Artur Barseghyan <artur.barseghyan@gmail.com>'
__copyright__ = '2013-2018 Artur Barseghyan'
__license__ = 'GPL 2.0/LGPL 2.1'
__all__ = (
    'CHANGED_NONEFIELD_VALUE',
    'ENDPOINT_URL',
    'INITIAL_NONEFIELD_VALUE',
)

ENDPOINT_URL = "http://example.com"
INITIAL_NONEFIELD_VALUE = "Lorem ipsum"
CHANGED_NONEFIELD_VALUE = "Dolor sit amet"



from __future__ import print_function

import logging

__title__ = 'nonefield.tests.base'
__author__ = 'Artur Barseghyan <artur.barseghyan@gmail.com>'
__copyright__ = '2013-2018 Artur Barseghyan'
__license__ = 'GPL 2.0/LGPL 2.1'
__all__ = (
    'LOG_INFO',
    'log_info',
    'OPTIONAL_SKIP',
    'optional_skip',
)


LOGGER = logging.getLogger(__name__)
LOG_INFO = True
TRACK_TIME = False


def log_info(func):
    """Logs some useful info."""
    if not LOG_INFO:
        return func

    def inner(self, *args, **kwargs):

        result = func(self, *args, **kwargs)

        LOGGER.debug('\n{0}'.format(func.__name__))
        LOGGER.debug('============================')
        if func.__doc__:
            LOGGER.debug('""" {0} """'.format(func.__doc__.strip()))
        LOGGER.debug('----------------------------')
        if result is not None:
            LOGGER.debug(result)
        LOGGER.debug('\n')

        return result
    return inner

OPTIONAL_SKIP = False


def optional_skip(func):
    """Simply skips the test."""
    def inner(self, *args, **kwargs):
        if OPTIONAL_SKIP:
            return
        return func(self, *args, **kwargs)
    return inner



import six

from django.utils.safestring import mark_safe

from rest_framework.fields import empty, Field

__title__ = 'nonefield.contrib.drf_integration.fields'
__author__ = 'Artur Barseghyan <artur.barseghyan@gmail.com>'
__copyright__ = '2013-2018 Artur Barseghyan'
__license__ = 'GPL 2.0/LGPL 2.1'
__all__ = ('NoneField',)


class NoneField(Field):
    """NoneField."""

    default_error_messages = {}
    initial = ''
    default_empty_html = ''

    def __init__(self, **kwargs):
        self.allow_blank = True
        self.trim_whitespace = kwargs.pop('trim_whitespace', True)
        self.raw_data = kwargs.pop('raw_data', {})
        super(NoneField, self).__init__(**kwargs)

    def run_validation(self, data=empty):
        return ''

    def to_internal_value(self, data):
        # We're lenient with allowing basic numerics to be coerced into
        # strings, but other types should fail. Eg. unclear if booleans
        # should represent as `true` or `True`, and composites such as lists
        # are likely user error.
        _not_isinstance_str_int_float = not isinstance(
            data, six.string_types + six.integer_types + (float,)
        )
        if isinstance(data, bool) or _not_isinstance_str_int_float:
            self.fail('invalid')
        value = six.text_type(data)
        return value.strip() if self.trim_whitespace else value

    def to_representation(self, value):
        return mark_safe(six.text_type(value))



import unittest

from django import forms
from django.test import RequestFactory, TestCase

from ..fields import NoneField
from .base import log_info
from .constants import (
    ENDPOINT_URL,
    INITIAL_NONEFIELD_VALUE,
    CHANGED_NONEFIELD_VALUE,
)

__all__ = ('NoneFieldTest',)
__author__ = 'Artur Barseghyan <artur.barseghyan@gmail.com>'
__copyright__ = '2013-2018 Artur Barseghyan'
__license__ = 'GPL 2.0/LGPL 2.1'


class MyForm(forms.Form):
    """Test form."""

    name = forms.CharField(required=True)
    static_text = NoneField(initial=INITIAL_NONEFIELD_VALUE)


class NoneFieldTest(TestCase):
    """Test the django-nonefield package."""

    def setUp(self):
        """Set up.

        :return:
        """

    @log_info
    def test_01_nonefield(self):
        """Test `nonefield.fields.NoneField`."""
        request_factory = RequestFactory()
        request = request_factory.post(
            ENDPOINT_URL,
            data={
                'name': "John Doe",
                'static_text': CHANGED_NONEFIELD_VALUE
            }
        )

        form = MyForm(
            data=request.POST,
            initial={'static_text': INITIAL_NONEFIELD_VALUE}
        )

        self.assertTrue(form.is_valid())

        self.assertEqual("John Doe", form.cleaned_data['name'])
        self.assertEqual(INITIAL_NONEFIELD_VALUE,
                         form.cleaned_data['static_text'])


if __name__ == '__main__':
    unittest.main()



import sys
import os
from setuptools import setup, find_packages

try:
    readme = open(os.path.join(os.path.dirname(__file__), 'README.rst')).read()
    readme = readme.replace('.. code-block:: none', '.. code-block::')
except:
    readme = ''

version = '0.3'

install_requires = [
    'django-nine>=0.1.13',
]

try:
    PY2 = sys.version_info[0] == 2
    LTE_PY26 = PY2 and (7 > sys.version_info[1])
    PY3 = sys.version_info[0] == 3
except:
    pass

setup(
    name='django-nonefield',
    version=version,
    description="A None field for Django.",
    long_description=readme,
    classifiers=[
        "Programming Language :: Python :: 2.7",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Environment :: Web Environment",
        "License :: OSI Approved :: GNU General Public License v2 (GPLv2)",
        "License :: OSI Approved :: GNU Lesser General Public License v2 or "
        "later (LGPLv2+)",
        "Framework :: Django",
        "Intended Audience :: Developers",
        "Operating System :: OS Independent",
        "Development Status :: 4 - Beta",
    ],
    keywords='forms, django, none field, django none field',
    author='Artur Barseghyan',
    author_email='artur.barseghyan@gmail.com',
    url='https://github.com/barseghyanartur/django-nonefield/',
    package_dir={'': 'src'},
    packages=find_packages(where='./src'),
    license='GPL 2.0/LGPL 2.1',
    install_requires=install_requires,
)



from django.forms.widgets import Widget
from django.utils.safestring import mark_safe

__title__ = 'nonefield.widgets'
__author__ = 'Artur Barseghyan <artur.barseghyan@gmail.com>'
__copyright__ = '2013-2018 Artur Barseghyan'
__license__ = 'GPL 2.0/LGPL 2.1'
__all__ = ('NoneWidget',)


class NoneWidget(Widget):
    """NoneWidget.

    To be used with content elements.
    """

    def render(self, name, value, attrs=None, **kwargs):
        """Render."""
        return mark_safe(value)
